@@ -12,7 +12,7 @@ class Releases:
             self.end = start
         else:
             self.end = end
-        r = requests.get('https://blooming-ravine-2170.herokuapp.com/releases?starts_after={}&ends_before={}'.format(self.start, self.end), headers={'content-type':'application/json'})
+        r = requests.get('https://mc-release-calendar.herokuapp.com/releases?starts_after={}&ends_before={}'.format(self.start, self.end), headers={'content-type':'application/json'})
         releases = r.json()
         self.maint='Not Open'
         self.master='Not Open'
